﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using UnityEngine;

namespace SWPP
{
    internal class Examples
    {
        public static string ModTag = " [SWPP]"; //Whilst not required, modded items should contain 'tags' at the end of their names to prevent errors in which two mods have an item of the same name.
        
        
        
        public static void Main()
        {
           
            ///HIGHLIGHT FROM HERE
            // Example Human - cam
            ModAPI.Register(
                new Modification()
                {
                    //change V this V to Android for androids - cam
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = ModTag + "Human person", //new item name with a suffix to assure it is globally unique
                    DescriptionOverride = "Just a dood.", //new item description
                    CategoryOverride = ModAPI.FindCategory("Star Wars Power Pack"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("Characters/Standard dood/thumb.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer 
                        var skin = ModAPI.LoadTexture("Characters/Standard dood/skin layer.png");
                        var flesh = ModAPI.LoadTexture("Characters/Standard dood/flesh layer.png");
                        var bone = ModAPI.LoadTexture("Characters/Standard dood/bone layer.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        //If you don't want to change the flesh and bone texture, change it to person.SetBodyTextures(skin); - cam
                        person.SetBodyTextures(skin, flesh, bone, 1);


                        //You don't really need to touch this, blood color doesn't even work lol - cam
                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
            ///TO HERE

            
            ///HIGHLIGHT FROM HERE
            // Example Blaster
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Blaster"), //item to derive from
                    NameOverride = "Example blaster", //new item name with a suffix to assure it is globally unique
                    DescriptionOverride = "Woah, example!", //new item description
                    CategoryOverride = ModAPI.FindCategory("Star Wars Power Pack"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("Characters/Standard dood/thumb.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //get the SpriteRenderer and replace its sprite with a custom one
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Characters/Standard dood/Gay Laser Cannon.png");
                        Instance.FixColliders();
                        Instance.GetComponent<BlasterBehaviour>().Clips = new AudioClip[3] 
                        //You can change the blaster sounds here and add more if you need to. - cam
                        { ModAPI.LoadSound("Characters/Standard dood/Gun 1.wav"),
                        ModAPI.LoadSound("Characters/Standard dood/Gun 2.wav"),
                        ModAPI.LoadSound("Characters/Standard dood/Gun 3.wav")};


                        foreach (Transform item in Instance.transform)
                        {
                            if (item.name.Contains("light"))
                            {
                                GameObject.Destroy(item.gameObject);
                            }
                            else if (item.name.Contains("glow"))
                            {
                                //google color selector on google and use the rgb output
                                item.gameObject.GetComponent<SpriteRenderer>().color = new Color32(215, 94, 255, 255);
                            }
                        }
                    }
                }
            );
            ///TO HERE
        }


    }
}
