﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using TMPro;
using UnityEngine;
using UnityEngine.Events;
using UnityEngine.UI;
using System.Reflection;
namespace SWPP
{
    public class Darkshear : PowerBase
    {
        GameObject Shield;
        Coroutine Coroutine = null;
         Vector3 OgGripPos;
        public Sprite ShieldSprite;

        public override void Start()
        {
            //We set our power activation type (Head,Chest,Hand)
            Activation = "Hand";

            //Always keep this
            DisablesGrips = true;
            base.Start();
        }

        //This is the actual power part of your power, this function will trigger when the activation limb is used.
        public override void UsePower()
        {
            //This if statement exists to check if your power is selected and enabled in the power menu
            if (Enabled)
            {
                if (!Shield)
                {
                    Shield = GameObject.Instantiate(ModAPI.FindSpawnable("Sword").Prefab);
                    Shield.transform.position = transform.position + -transform.up * 1.3f;
                    Shield.transform.eulerAngles = transform.eulerAngles + new Vector3(0, 0, 180);
                    gameObject.AddComponent<FixedJoint2D>().connectedBody = Shield.GetComponent<Rigidbody2D>();
                    Shield.GetComponent<SpriteRenderer>().sprite = ShieldSprite;
                    Shield.FixColliders();
                    Shield.transform.SetParent(GetComponent<LimbBehaviour>().Person.transform);
                    Shield.gameObject.AddComponent<UseEventTrigger>().Action = () =>
    {
      Destroy(gameObject.GetComponent<FixedJoint2D>());
    };
                    foreach (var body in GetComponent<LimbBehaviour>().Person.Limbs)
                    {
                            Physics2D.IgnoreCollision(Shield.GetComponent<Collider2D>(), body.GetComponent<Darkshear>().Shield.GetComponent<Collider2D>());
                    }
                }
                else if (Shield)
                {
                    GameObject.Destroy(Shield);
                }
            }
        }


                public void Update()
        {
            if (Shield && Coroutine == null)
            {
                Coroutine = StartCoroutine(ParticalEffect());
            }
        }

        public virtual IEnumerator ParticalEffect()
        {
            ModAPI.CreateParticleEffect("Vapor", Shield.transform.position).transform.localScale = Vector3.one * 3.5f;
            yield return new WaitForSeconds(0.6f);
            Coroutine = null;
        }
        

        /// <summary>
        /// Set up the power on a character.
        /// </summary>
        /// <param name="body">The selected limb of the user.</param>
        /// <param name="person">The PersonBehaviour of the user. (body.Person)</param>
        /// <param name="Instance">The overall instance of the user. ( body.Person.gameObject)</param>
        public static void SetUpPower(LimbBehaviour body, PersonBehaviour person,Sprite powerIcon = null,string powerName = "Darkshear")
        {
            //This checks if the person already has the power, if they don't we give it to them (duplicates are bad) NOTE:make sure to change the class to your new power class
            if (!body.GetComponent<Darkshear>() || body.GetComponent<Darkshear>().PowerName != powerName)
            {
                //Adds your new power to the person NOTE:make sure to change the class to your new power class
                var Power = body.gameObject.AddComponent<Darkshear>();
                
                //This sets the power's icon, make sure you add the your new icon to the ResourceStorage NOTE:make sure to change the class to your new power class
                if(powerIcon == null)
                {
                    Power.PowerIcon = SWPP.IconDarkshear;
                }
                else
                {
                    Power.PowerIcon = powerIcon;
                }

                Power.PowerName = powerName;

                body.gameObject.AddComponent<UseEventTrigger>().Action = () =>
                {
                    //This triggers your power NOTE:make sure to change the class to your new power class
                    Power.UsePower();
                };
            }
        }
    }
}


