﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using TMPro;
using UnityEngine;
using UnityEngine.Events;
using UnityEngine.UI;
using System.Reflection;
namespace SWPP
{
    public class ForceDrain : PowerBase, Messages.IUseContinuous
    {
        private bool Choking;
        private LimbBehaviour Head;
        private int val = 0;

        public override void Start()
        {
            //We set our power activation type (Head,Chest,Hand)
            Activation = "Hand";

            //Always keep this
            DisablesGrips = false;
            base.Start();
        }
        
        //This is the actual power part of your power, this function will trigger when the activation limb is used.
        public override void UsePower()
        {
            //This if statement exists to check if your power is selected and enabled in the power menu
            if (Enabled)
            {
                if (!this.Choking)
                {
                    this.val = 1;
                    var cast = Physics2D.CircleCast(this.transform.position, ModAPI.PixelSize * 3f, -this.transform.up, 15f, LayerMask.GetMask("Objects")); //we use circle cast because being slightly off would be annoying.
                    if (cast.transform != null && cast.transform.root != this.transform.root)
                    {
                        if (cast.transform.gameObject.TryGetComponent<LimbBehaviour>(out var limb))
                        {
                            this.Head = limb.Person.Limbs[2];
                            this.Choking = true;
                            	var q = ModAPI.CreateParticleEffect("RedBarrelExplosion", Head.gameObject.transform.position);
        var w = q.GetComponent<ParticleSystem>().main;
                w.startColor = new Color(252f, 0f, 0f);
                        }
                    }
                }
            }
        }

        public void UseContinuous(ActivationPropagation prop)
        {
            //This if statement exists to check if your power is selected and enabled in the power menu
            if (Enabled)
            {
                this.val += 2;
                this.Choking = true;
            }
        }

        public void Update()
        {
            if (this.Choking)
            {
                this.val = Mathf.Clamp(this.val, -1, 2);
                if (this.val > 0) //just to stop it going into large negative numbers without using clamp
                {
                    this.val -= 1;
                }
                if (this.val < 1)
                {
                    this.Choking = false;
	var q2 = ModAPI.CreateParticleEffect("Vapor", Head.gameObject.transform.position);
        var w2 = q2.GetComponent<ParticleSystem>().main;
                w2.startColor = new Color(252f, 0f, 0f);
                this.Head.Person.OxygenLevel = -10f;
                this.Head.Person.Consciousness = 0;
                }
                this.Head.Person.OxygenLevel -= Time.deltaTime / 12f;
                this.Head.Person.PainLevel += Time.deltaTime * 6f;
	var q = ModAPI.CreateParticleEffect("Vapor", Head.gameObject.transform.position);
        var w = q.GetComponent<ParticleSystem>().main;
                w.startColor = new Color(252f, 0f, 0f);
                this.gameObject.GetComponent<CirculationBehaviour>().AddLiquid(Liquid.GetLiquid("LIFE SERUM"), 1f);
            }
        }

        /// <summary>
        /// Set up the power on a character.
        /// </summary>
        /// <param name="body">The selected limb of the user.</param>
        /// <param name="person">The PersonBehaviour of the user. (body.Person)</param>
        /// <param name="Instance">The overall instance of the user. ( body.Person.gameObject)</param>
        public static void SetUpPower(LimbBehaviour body, PersonBehaviour person,Sprite powerIcon = null,string powerName = "Force Drain")
        {
            //This checks if the person already has the power, if they don't we give it to them (duplicates are bad) NOTE:make sure to change the class to your new power class
            if (!body.GetComponent<ForceDrain>() || body.GetComponent<ForceDrain>().PowerName != powerName)
            {
                //Adds your new power to the person NOTE:make sure to change the class to your new power class
                var Power = body.gameObject.AddComponent<ForceDrain>();
                
                //This sets the power's icon, make sure you add the your new icon to the ResourceStorage NOTE:make sure to change the class to your new power class
                if(powerIcon == null)
                {
                    Power.PowerIcon = SWPP.IconForceDrain;
                }
                else
                {
                    Power.PowerIcon = powerIcon;
                }

                Power.PowerName = powerName;

                body.gameObject.AddComponent<UseEventTrigger>().Action = () =>
                {
                    //This triggers your power NOTE:make sure to change the class to your new power class
                    Power.UsePower();
                };
            }
        }
    }
}